"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var GroupBuilder_1 = __importDefault(require("./GroupBuilder"));
// @ts-ignore
var becke_ch__regex__s0_0_v1__base__pl__lib_1 = __importDefault(require("becke-ch--regex--s0-0-v1--base--pl--lib"));
var TreeRegexp = /** @class */ (function () {
    function TreeRegexp(regexp) {
        this.regexp = 'string' === typeof regexp ? new RegExp(regexp) : regexp;
        this.regex = new becke_ch__regex__s0_0_v1__base__pl__lib_1.default(this.regexp.source, this.regexp.flags);
        this.groupBuilder = TreeRegexp.createGroupBuilder(this.regex);
    }
    TreeRegexp.createGroupBuilder = function (regexp) {
        var source = regexp.source;
        var stack = [new GroupBuilder_1.default()];
        var groupStartStack = [];
        var escaping = false;
        var charClass = false;
        for (var i = 0; i < source.length; i++) {
            var c = source[i];
            if (c === '[' && !escaping) {
                charClass = true;
            }
            else if (c === ']' && !escaping) {
                charClass = false;
            }
            else if (c === '(' && !escaping && !charClass) {
                groupStartStack.push(i);
                var nonCapturing = TreeRegexp.isNonCapturing(source, i);
                var groupBuilder = new GroupBuilder_1.default();
                if (nonCapturing) {
                    groupBuilder.setNonCapturing();
                }
                stack.push(groupBuilder);
            }
            else if (c === ')' && !escaping && !charClass) {
                var gb = stack.pop();
                var groupStart = groupStartStack.pop();
                if (gb.capturing) {
                    gb.source = source.substring(groupStart + 1, i);
                    stack[stack.length - 1].add(gb);
                }
                else {
                    gb.moveChildrenTo(stack[stack.length - 1]);
                }
            }
            escaping = c === '\\' && !escaping;
        }
        return stack.pop();
    };
    TreeRegexp.isNonCapturing = function (source, i) {
        // Regex is valid. Bounds check not required.
        if (source[i + 1] != '?') {
            // (X)
            return false;
        }
        if (source[i + 2] != '<') {
            // (?:X)
            // (?=X)
            // (?!X)
            return true;
        }
        // (?<=X) or (?<!X) else (?<name>X)
        return source[i + 3] == '=' || source[i + 3] == '!';
    };
    TreeRegexp.prototype.match = function (s) {
        var match = this.regex.exec(s);
        if (!match) {
            return null;
        }
        var groupIndex = 0;
        var nextGroupIndex = function () { return groupIndex++; };
        return this.groupBuilder.build(match, nextGroupIndex);
    };
    return TreeRegexp;
}());
exports.default = TreeRegexp;
//# sourceMappingURL=TreeRegexp.js.map