"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatUndefinedParameterType = exports.formatUndefinedParameterTypes = exports.formatIssue = exports.isIssue = exports.isWarning = exports.isFailure = void 0;
const indent_string_1 = __importDefault(require("indent-string"));
const status_1 = __importDefault(require("../../status"));
const test_case_attempt_formatter_1 = require("./test_case_attempt_formatter");
function isFailure(result) {
    return (result.status === status_1.default.AMBIGUOUS ||
        result.status === status_1.default.UNDEFINED ||
        (result.status === status_1.default.FAILED && !result.willBeRetried));
}
exports.isFailure = isFailure;
function isWarning(result) {
    return (result.status === status_1.default.PENDING ||
        (result.status === status_1.default.FAILED && result.willBeRetried));
}
exports.isWarning = isWarning;
function isIssue(result) {
    return isFailure(result) || isWarning(result);
}
exports.isIssue = isIssue;
function formatIssue({ colorFns, cwd, number, snippetBuilder, testCaseAttempt, supportCodeLibrary, }) {
    const prefix = `${number.toString()}) `;
    const formattedTestCaseAttempt = test_case_attempt_formatter_1.formatTestCaseAttempt({
        colorFns,
        cwd,
        snippetBuilder,
        testCaseAttempt,
        supportCodeLibrary,
    });
    const lines = formattedTestCaseAttempt.split('\n');
    const updatedLines = lines.map((line, index) => {
        if (index === 0) {
            return `${prefix}${line}`;
        }
        return indent_string_1.default(line, prefix.length);
    });
    return updatedLines.join('\n');
}
exports.formatIssue = formatIssue;
function formatUndefinedParameterTypes(undefinedParameterTypes) {
    const output = [`Undefined parameter types:\n\n`];
    const withLatest = {};
    undefinedParameterTypes.forEach((parameterType) => {
        withLatest[parameterType.name] = parameterType;
    });
    output.push(Object.values(withLatest)
        .map((parameterType) => `- ${formatUndefinedParameterType(parameterType)}`)
        .join('\n'));
    output.push('\n\n');
    return output.join('');
}
exports.formatUndefinedParameterTypes = formatUndefinedParameterTypes;
function formatUndefinedParameterType(parameterType) {
    return `"${parameterType.name}" e.g. \`${parameterType.expression}\``;
}
exports.formatUndefinedParameterType = formatUndefinedParameterType;
//# sourceMappingURL=issue_helpers.js.map