"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var GherkinDocument_1 = __importDefault(require("../gherkin/GherkinDocument"));
var messages_1 = require("@cucumber/messages");
var react_accessible_accordion_1 = require("react-accessible-accordion");
var UriContext_1 = __importDefault(require("../../UriContext"));
var GherkinQueryContext_1 = __importDefault(require("../../GherkinQueryContext"));
var CucumberQueryContext_1 = __importDefault(require("../../CucumberQueryContext"));
var StatusIcon_1 = __importDefault(require("../gherkin/StatusIcon"));
var GherkinDocumentList = function (_a) {
    var gherkinDocuments = _a.gherkinDocuments;
    var gherkinQuery = react_1.default.useContext(GherkinQueryContext_1.default);
    var cucumberQuery = react_1.default.useContext(CucumberQueryContext_1.default);
    var gherkinDocs = gherkinDocuments === undefined
        ? gherkinQuery.getGherkinDocuments()
        : gherkinDocuments;
    var entries = gherkinDocs.map(function (gherkinDocument) {
        var gherkinDocumentStatus = gherkinDocument.feature
            ? cucumberQuery.getWorstTestStepResult(cucumberQuery.getPickleTestStepResults(gherkinQuery.getPickleIds(gherkinDocument.uri))).status
            : messages_1.messages.TestStepFinished.TestStepResult.Status.UNDEFINED;
        return [gherkinDocument.uri, gherkinDocumentStatus];
    });
    var gherkinDocumentStatusByUri = new Map(entries);
    // Pre-expand any document that is *not* passed - assuming this is what people want to look at first
    var preExpanded = gherkinDocs
        .filter(function (doc) {
        return gherkinDocumentStatusByUri.get(doc.uri) !==
            messages_1.messages.TestStepFinished.TestStepResult.Status.PASSED;
    })
        .map(function (doc) { return doc.uri; });
    return (react_1.default.createElement("div", { className: "gherkin-document-list" },
        react_1.default.createElement(react_accessible_accordion_1.Accordion, { allowMultipleExpanded: true, allowZeroExpanded: true, preExpanded: preExpanded }, gherkinDocs.map(function (doc) {
            var gherkinDocumentStatus = gherkinDocumentStatusByUri.get(doc.uri);
            return (react_1.default.createElement(react_accessible_accordion_1.AccordionItem, { key: doc.uri, uuid: doc.uri },
                react_1.default.createElement(react_accessible_accordion_1.AccordionItemHeading, null,
                    react_1.default.createElement(react_accessible_accordion_1.AccordionItemButton, null,
                        react_1.default.createElement("span", { className: "cucumber-feature__icon" },
                            react_1.default.createElement(StatusIcon_1.default, { status: gherkinDocumentStatus })),
                        react_1.default.createElement("span", null, doc.uri))),
                react_1.default.createElement(react_accessible_accordion_1.AccordionItemPanel, null,
                    react_1.default.createElement(UriContext_1.default.Provider, { value: doc.uri },
                        react_1.default.createElement(GherkinDocument_1.default, { gherkinDocument: doc })))));
        }))));
};
exports.default = GherkinDocumentList;
//# sourceMappingURL=GherkinDocumentList.js.map