"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var assert_1 = __importDefault(require("assert"));
var messages_1 = require("@cucumber/messages");
var FeatureSearch_1 = __importDefault(require("../../src/search/FeatureSearch"));
var utils_1 = require("./utils");
describe('FeatureSearch', function () {
    var featureSearch;
    var gherkinDocument;
    beforeEach(function () {
        featureSearch = new FeatureSearch_1.default();
        gherkinDocument = messages_1.messages.GherkinDocument.create({
            uri: 'some/feature.file',
            feature: utils_1.makeFeature('this exists', 'description feature', []),
        });
        featureSearch.add(gherkinDocument);
    });
    context('#search', function () {
        it('returns an empty array when there are no hits', function () {
            var searchResult = featureSearch.search('banana');
            assert_1.default.deepStrictEqual(searchResult, []);
        });
        it('finds results with equal feature name', function () {
            var searchResult = featureSearch.search('this exists');
            assert_1.default.deepStrictEqual(searchResult, [gherkinDocument.feature]);
        });
        it('finds results with substring of feature name', function () {
            var searchResult = featureSearch.search('exists');
            assert_1.default.deepStrictEqual(searchResult, [gherkinDocument.feature]);
        });
        it('finds results with equal feature description', function () {
            var searchResult = featureSearch.search('description');
            assert_1.default.deepStrictEqual(searchResult, [gherkinDocument.feature]);
        });
    });
});
//# sourceMappingURL=FeatureSearchTest.js.map